#! /usr/bin/Rscript --vanilla

# Wages of Paycuts: Evidence from a Field Experiment
# Paper Authors: Daniel Chen and John Horton
# Code Author: John Horton
# Date: July 10, 2013 

library(devtools)

devtools::install_github("johnjosephhorton/JJHmisc")
library(JJHmisc)

devtools::install("../WageCutsR", local = TRUE)
library(WageCutsR)

chisq.test(with(data,table(male,G)))
chisq.test(with(data,table(uscan,G)))
chisq.test(with(data,table(gt10,G)))

#' Logit Robustness Check

m.uptake.logit <- glm(add ~ group, family = "binomial", data = df.uptake)
summary(m.uptake.logit)
library(mfx)
logitmfx(add ~ group, data = df.uptake)

m <- lm(add ~ I(group=="FairnessPrimedWC"), data = subset(df.no_3, group %in% c("WageCut", "FairnessPrimedWC")))
x <- subset(df.no_3, group == "WageCut")$add
y <- subset(df.no_3, group == "FairnessPrimedWC")$add
t.test(x,y)

## > t.test(x,y)

## 	Welch Two Sample t-test

## data:  x and y
## t = 0.498, df = 33.46, p-value = 0.6217
## alternative hypothesis: true difference in means is not equal to 0
## 95 percent confidence interval:
##  -0.2417989  0.3986616
## sample estimates:
## mean of x mean of y 
## 0.4117647 0.3333333 

m.error.any <- lm(log(e4) ~ any.cut + prior.error, data = df.error)
waldtest(m.error.any)

m.error.alone <- lm(e4.z ~ group + prior.error, data = df.error)

m.error.alone.i <- lm(e4.z ~ prior.error * group, data = df.error)
waldtest(m.error.alone, m.error.alone.i)

REDO.BOOTSTRAP <- FALSE
if (REDO.BOOTSTRAP){
    e2 <- with(df.error, log(e4))
    e1 <- with(df.error, prior.error)
    cor(e1, e2) # point estimate 
    sim.cor <- function(){
        indices <- sample(1:length(e1), replace = TRUE)
        cor(e1[indices], e2[indices])
    }
    bs.corr <- replicate(1000000, sim.cor())
    quantile(bs.corr, probs = c(0.05/2, 1.0 - 0.05/2))
    ## > quantile(bs.corr, probs = c(0.05/2, 1.0 - 0.05/2))
    ##      2.5%     97.5% 
    ## 0.1373868 0.5645687 
} 

quantile(bs.corr, probs = c(0.05/2, 1.0 - 0.05/2))

m.error.alone <- lm(e4.z ~ group + prior.error, data = df.error)


X <- subset(df.no_1, select = c(advice.z, trust.z, survey))
m.pca <- prcomp(X, retx = TRUE, center = TRUE, scale = TRUE)

df.no_1$p1 <- predict(m.pca)[,1]
df.no_1$p2 <- predict(m.pca)[,2]

# plot principal component transformations 
g <- ggplot(data = df.no_1, aes(x = p1, y = p2, colour = group)) + geom_point() + facet_wrap(~group, ncol = 4)
# writeImage(g, "pca", width = 5, height = 5)

pdf("../../writeup/images/pca.pdf", width = 9, height = 4)
  print(g)
dev.off() 

###############################################
# UPTAKE - WORKER WILLINGESS TO ACCEPT WAGE CUT 
###############################################

############
#' Framings
############
# define datasets for analysis 

##############
# Unframed Cut 
##############
# define dataset 

#########################
#' Follow-on performance
#########################

#########################
#' Consummate Performance 
#########################


m.advice <- lm(advice.z ~ group + prior.error, data = df.no_1)
m.trust <- lm(trust.z ~ group + prior.error, data = df.no_1)
m.patient <- lm(patient ~ group + prior.error, data = df.no_1)
m.survey <- lm(survey ~ group + prior.error, data = df.no_1)

waldtest(m.advice)
waldtest(m.trust)
waldtest(m.patient)
waldtest(m.survey)

#' Games Comparisons
#' Did doing a fourth paragraph matter? 

############
#' Attrition
############
# models 
df.games <- subset(data, group %in% c("Control", "OnlyGames"))
df.games$group <- with(df.games, factor(group))
df.games <- within(df.games, group <- relevel(group, ref = "OnlyGames"))
m.games.attr.advice <- lm(advice.z ~ I(group == "Control"), data = df.games)
m.games.attr.survey <- update(m.games.attr.advice, survey ~ .)
m.games.attr.trust <- update(m.games.attr.advice, trust.z ~ .)
#' results
summary(m.games.attr.advice)
summary(m.games.attr.survey)
summary(m.games.attr.trust)
stargazer(m.games.attr.advice, m.games.attr.survey, m.games.attr.trust, type = "text")

#############
# Any wage cut
#############

summary(m.games.any.cut.advice)
summary(m.games.any.cut.trust)
                                       # results
stargazer(m.games.any.cut.advice, m.games.any.cut.trust, m.games.any.cut.survey, type = "text")

################
# Justifications 
################

df.games <- subset(df.no_1)
df.games <- within(df.games, group <- relevel(group, ref = "OnlyGames"))
#df.games <- subset(df.no_1, group %in% c("Profit", "No Cut", "Productivity"))

m.survey <- lm(survey ~ meta, data = df.games)
m.survey.profit <- lm(survey ~ I(group == "Profit"), data = df.games)

m.profits <- lm(survey ~ I(group == "Profit"), data = subset(df.games, group != "ProductivityWC"))
m.profits.any <- lm(survey ~ I(group == "Profit"), data = subset(df.games, group != "OnlyGames"))
#m.pc1 <- lm(p1 ~ I(group == "Profit"), data = subset(df.games, group != "Productivity"))
#m.pc2 <- lm(p2 ~ I(group == "Profit"), data = subset(df.games, group != "Productivity"))


df.games <- subset(data, !(group %in% c("OnlyGames", "Control", "UnframedWC")))

m.profit <- lm(survey ~ I(group == "ProfitWC"), data = data)

m.profit <- lm(survey ~ I(group == "ProfitWC"), data = data)

m.unreasonable <- lm(survey ~ meta, data = df.games)

stargazer(m.profit, m.unreasonable, type = "text")



