#######################
# TABLE 1: Uptake Table 
#######################

df.no_3$group <- with(df.no_3, reorder(group, G_numeric, mean))

m.uptake <- lm(add ~ group, data=df.no_3)
m.uptake.c <- update(m.uptake, . ~ . + male + uscan + gt10 + eng +  I(log1p(e1 + e2 + e3)))
m.uptake.logit <- glm(add ~ group, data = df.no_3, family = "binomial")

models <- list()
models[[ "(1)" ]] = robust(m.uptake)
models[[ "(2)" ]] = robust(m.uptake.c)
# models[[ "(3)" ]] = m.uptake.logit
models[[ "summary.stats" ]] = c("R-squared", "N")


createRenames <- function(first.column.width, v.spacing){
    renames <- list()
    renames[[ 'group: Neighbor/Control (same 10c)' ]] = latex.row.label(
               first.column.width,
               group.desc.long["neighbor"],
               v.spacing)
    renames[[ 'group: Primed/Control (same 10c)' ]] = latex.row.label(
               first.column.width,
               group.desc.long["fairness"],
               v.spacing)
    renames[[ 'group: Productivity/Control (same 10c)' ]] = latex.row.label(
               first.column.width,
               group.desc.long["productivity"],
               v.spacing)
    renames[[ 'group: Profit/Control (same 10c)' ]] = latex.row.label(
               first.column.width,
               group.desc.long["profit"],
               v.spacing)
    renames[[ 'group: Unexplained/Control (same 10c)' ]] = latex.row.label(
               first.column.width,
               group.desc.long["unexplained"], v.spacing)
    renames[[ 'group: Unframed/Control (same 10c)' ]] = latex.row.label(
           first.column.width, group.desc.long["unframed"], v.spacing)
    renames[[ 'group: No Cut/Control (same 10c)' ]] = latex.row.label(
           first.column.width, group.desc.long["nocut"], v.spacing)
    renames[[ 'male' ]] = latex.row.label(
               first.column.width,
               "Male",
               v.spacing)
    renames[[ 'uscan' ]] = latex.row.label(
               first.column.width,
               "From US/Canada",
               v.spacing)
    renames[[ 'gt10' ]] = latex.row.label(
               first.column.width,
               "Spends more than 10 hours/week working online",
               v.spacing)
    renames[[ 'eng' ]] = latex.row.label(
               first.column.width,
               "First language is English",
               v.spacing)
    renames[[ 'I(log1p(e1 + e2 + e3))' ]] = latex.row.label(
               first.column.width,
               "Log cumulative errors from first phase",
               v.spacing)
    renames[[ 'group: Control (same 10c)/No Cut' ]] = latex.row.label(
               first.column.width,
               group.desc.long["control"],
               v.spacing)
    renames[[ 'group: Neighbor/No Cut' ]] = latex.row.label(
               first.column.width,
               group.desc.long["neighbor"],
               v.spacing)
    renames[[ 'group: Primed/No Cut' ]] = latex.row.label(
               first.column.width,
               group.desc.long["fairness"],
               v.spacing)
    renames[[ 'group: Productivity/No Cut' ]] = latex.row.label(
               first.column.width,
               group.desc.long["productivity"],
               v.spacing)
    renames[[ 'group: Profit/No Cut' ]] = latex.row.label(
               first.column.width,
               group.desc.long["profit"],
               v.spacing)
    renames[[ 'group: Unexplained/No Cut' ]] = latex.row.label(
               first.column.width,
               group.desc.long["unexplained"],
               v.spacing)
    renames[[ 'group: Unframed/No Cut' ]] = latex.row.label(
               first.column.width,
               group.desc.long["unframed"],
               v.spacing)
    renames[[ 'prior.error' ]] = latex.row.label(
               first.column.width,
               "Log cumulative errors from first phase",
               v.spacing)
    renames
}

#renames <- createRenames(first.column.width = 9.5, v.spacing = 15) 
renames <- createRenames(first.column.width = 7.0, v.spacing = 16)

out.file <- paper.tables[["uptake"]]$writepath 
regression.table(models, renames, out.file)

n <- 38
n.line <- fix.sample.size.line(get.line(n, out.file))
kill.lines(n, n, out.file)
insert.note(n -1, n.line, out.file)

insert.note(10,
            "& & \\multicolumn{3}{c}{Workers accepted wage offer:}  \\\\ \n ", out.file)
insert.note(11, "\\cmidrule(lr){3-5} \n ", out.file)

####################
# Adverse Selection?
####################

df.adverse <- subset(df.no_3, group = c("Control (same 10c)", "Profit", "Primed"))

df.adverse$bad.reason <- with(df.adverse, I(group == "Profit" | group == "Primed" | group == "Unexplained"))
m.adverse <- lm(prior.error ~ add*bad.reason, data = df.adverse) 

summary(m.adverse)

###########################################################
# TABLE 2: ERROR ANALYSIS - DID WORKERS MAKE MORE MISTAKES? 
###########################################################

ggplot(data = df.no_3, aes(x = log1p(e4))) + geom_density()

#m.error <- lm(log(e4) ~ group, data = df.no_3)
df.error <- subset(df.no_3, e4 > 0 & e4 < 200)
df.error$e4.z <- with(df.error, (log(e4) - mean(log(e4)) )/(sd(log(e4))))

m.error <- lm(e4.z ~ group, data = df.error)
m.error.c <- update(m.error, . ~ . + I(log1p(e1 + e2 + e3))) 

models <- list()
models[[ "(1)" ]] = m.error
models[[ "(2)" ]] = m.error.c
models[[ "summary.stats" ]] = c("R-squared", "N")

renames <- createRenames(first.column.width = 6.0, v.spacing = 20) 

out.file <- paper.tables[["error"]]$writepath 


regression.table(models, renames, out.file)

insert.note(10,
            "& & \\multicolumn{3}{c}{Follow-on task error rate (z-score):}  \\\\ \n ", out.file)
insert.note(11, "\\cmidrule(lr){3-5} \n ", out.file)


####################
# ERROR RATES FIGURE 
####################

g <- qplot(group,log(e4), geom="boxplot", 
           data = subset(data, group!="No Cut")) + 
  geom_jitter(alpha=.5) + coord_flip() + theme_bw() + coord_flip()

#print(g)

m <- lm(survey ~ G - 1, data = data)
effect <- coef(m)
se <- sqrt(diag(vcov(m)))
G <- c(1, 2, 3, 4, 5, 6, 7, 8)
df <- data.frame(effect = effect, se = se, G = G)
df$group <- sapply(df$G, function(x) groups.desc[x])
df$meta <- sapply(df$G, function(x) meta.desc[x])

g <- qplot(effect, group, data = df) + 
  xlab("Fraction of subjects agreeing to take a survey")  + 
  ylab("Exerimental groups") + 
  geom_errorbarh(aes(xmin = effect - 2*se, xmax = effect + 2*se))  + 
  facet_grid(meta ~ ., space="free", scales="free") +   
  theme_bw() + theme(strip.text.y = element_text(size = 8, angle = 0))

# print(g)

###############
# ADVICE FIGURE 
###############

m <- lm(I(advice > 0) ~ G -1, data = data)
effect <- coef(m)
se <- sqrt(diag(vcov(m)))
G <- c(1, 2, 3, 4, 5, 6, 7, 8)
df <- data.frame(effect = effect, se = se, G = G)

df$group <- sapply(df$G, function(x) groups.desc[x])
df$meta <- sapply(df$G, function(x) meta.desc[x])

g <- qplot(effect, group, data = df) + 
    xlab("Fraction of subjects agreeing to offer advice")  + 
    ylab("Exerimental groups") + 
    facet_grid(meta ~ ., space="free", scales="free") +   
    geom_errorbarh(aes(xmin = effect - 2*se, xmax = effect + 2*se)) + 
    theme_bw() +
    theme(strip.text.y = element_text(size = 8, angle = 0))

##########################################
# TABLE 3: CONSUMMATE PERFORMANCE MEASURES 
##########################################

# advice (z-score)
# trust (z-score) - amount 
# patience (binary)
# survey  (binary) 

# create z-scores 
data <- within(data, {
               advice.z = ( advice - mean(advice)) / sd(advice)
               trust.z = (trust - mean(trust)) / sd(trust)
               prior.error = log(e1 + e2 + e3)
           })

df.no_1 <- data
df.no_1$group <- factor(df.no_1$group)
df.no_1$group <- relevel(df.no_1$group, ref= "OnlyGames")
df.no_1$group <- with(df.no_1, reorder(group, G_numeric, mean))
    
m.advice <- lm(advice.z ~ group + prior.error, data = df.no_1)
m.trust <- lm(trust.z ~ group + prior.error, data = df.no_1)
m.patient <- lm(patient ~ group + prior.error, data = df.no_1)
m.survey <- lm(survey ~ group + prior.error, data = df.no_1)

models <- list()
table.column.width <- 2.0
models[[ latex.column.label(table.column.width, 1, "Trust in employer's trustworthiness (z-score)") ]] = m.trust
models[[ latex.column.label(table.column.width, 2, "Willing to wait for payment from employer (1/0)") ]] = m.patient
models[[ latex.column.label(table.column.width, 3, "Advice for task completion to peers (length z-score)") ]] = m.advice
models[[ latex.column.label(table.column.width, 4, "Willing to take follow-on survey later (1/0)") ]] = m.survey
models[[ "summary.stats" ]] = c("R-squared", "N")

renames <- createRenames(first.column.width = 4.5, v.spacing = 25) 

out.file <- paper.tables[["combinedOutcomes"]]$writepath 
regression.table(models, renames, out.file)

################################
# APPENDIX - MORE SPECIFICATIONS  
################################



## models <- list()
## models[[ "(1)" ]] = robust(m.trust)
## models[[ "(2)" ]] = robust(m.trust.c)
## models[[ "(3)" ]] = robust(m.patient)
## models[[ "(4)" ]] = robust(m.patient.c)
## models[[ "summary.stats" ]] = c("R-squared", "N")

## out.file <- paper.tables[["trustAndPatience"]]$writepath 
## regression.table(models, renames, out.file)

## insert.note(12,
##             "&& \\multicolumn{3}{c}{Trust:} && \\multicolumn{3}{c}{Patience:}  \\\\ \n ", out.file)
## #insert.note(11, "\\cmidrule(lr){3-5} \n ", out.file)


## ######################
## # ADVICE & COOPERATION
## ######################

## m.advice <- lm(advice ~ group, data= df.no_1)
## m.advice.c <- update(m.advice, . ~ . + male + uscan + gt10 + eng +  I(log(e1 + e2 + e3 + 1)))
 
## m.advice.any <- update(m.advice, advice2 ~ .)
## m.advice.any.c <- update(m.advice.c, advice2 ~ .)

## m.coop <- update(m.advice, survey ~ . )
## m.coop.c <- update(m.advice.c, survey ~ .)

## models <- list()
## models[[ "(1)" ]] = robust(m.advice)
## models[[ "(2)" ]] = robust(m.advice.c)
## models[[ "(3)" ]] = robust(m.advice.any)
## models[[ "(4)" ]] = robust(m.advice.any.c)
## models[[ "(5)" ]] = m.coop
## models[[ "(6)" ]] = m.coop.c

## models[[ "summary.stats" ]] = c("R-squared", "N")

## out.file <- paper.tables[["adviceAndCooperation"]]$writepath 
## regression.table(models, renames, out.file)


createLaTeXparameters(lst, path = "../../writeup/parameters.tex")
